import React, { useEffect, useRef, useState } from "react";
import Chart from "chart.js/auto";
import Utils from "chart.js";
interface ChartData {
  message: string;
  data: {
    labels: string[];
    datasets: {
      data: number[];
      label: string;
      borderColor: string;
      backgroundColor: string;
      fill: boolean;
    }[];
  }[];
}

const LineChart: React.FC = () => {
  const [chartData, setChartData] = useState<ChartData | null>(null);
  const chartRef = useRef<Chart | null>(null);
  const labels = ["monday","s","d","e","e","y"];
  const d = {
    labels: labels,
    datasets: [{
      label: 'My First Dataset',
      data: [65, 59, 80, 81, 56, 55, 40],
      fill: false,
      borderColor: 'rgb(75, 192, 192)',
      tension: 0.1
    }]
  };
  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await fetch("http://localhost:3000/api/chartdata");
        if (!response.ok) {
          throw new Error("Failed to fetch data");
        }
        const data = await response.json();
        setChartData(data);
      } catch (error) {
        console.error("Error fetching chart data:", error);
      }
    };

    fetchData();

    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, []);

  useEffect(() => {
    if (!chartData) return;

    const canvas = document.getElementById("chart") as HTMLCanvasElement | null;
    if (canvas) {
      const ctx = canvas.getContext("2d");
      if (ctx) {
        if (chartRef.current) {
          chartRef.current.destroy();
        }
        chartRef.current = new Chart(ctx, {
          type: "line",
          data: {
            labels: chartData.data[0].labels,
            datasets: chartData.data[0].datasets.map(dataset => ({
              ...dataset,
              data: dataset.data.slice()
            })),
          },
          
        });
      }
    }

    // Cleanup function to ensure any existing chart is destroyed when component unmounts
    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, [chartData]);
  console.log(chartData)
  return (
    <div>
      <canvas id="chart"></canvas>
    </div>
  );
};

export default LineChart;
